@@ -1,11 +1,11 @@
 package bartMachine;
 
-import gnu.trove.list.array.TDoubleArrayList;
-import gnu.trove.list.array.TIntArrayList;
-
 import java.util.ArrayList;
 import java.util.Collection;
 
+import it.unimi.dsi.fastutil.doubles.DoubleArrayList;
+import it.unimi.dsi.fastutil.ints.IntArrayList;
+
 /**
  * A class that contains many generally useful convenience methods.
  * 
@@ -35,7 +35,7 @@ public class Tools {
 	 * @param joinby	the token that joins the substrings
 	 * @return			the final product: str1 + joinby + str2 + . . . + strN
 	 */	
-	public static String StringJoin(TIntArrayList all, String joinby){
+	public static String StringJoin(IntArrayList all, String joinby){
 		if (all == null){
 			return " NULL ARRAY ";
 		}		
@@ -88,7 +88,7 @@ public class Tools {
 	 * @param all		the collection of substrings
 	 * @return			the final product: str1 + joinby + str2 + . . . + strN
 	 */	
-	public static String StringJoin(TIntArrayList all){
+	public static String StringJoin(IntArrayList all){
 		return StringJoin(all.toArray(), ", ");
 	}	
 	
@@ -122,7 +122,7 @@ public class Tools {
 	 * @param all		the collection of substrings
 	 * @return			the final product: str1 + joinby + str2 + . . . + strN
 	 */	
-	public static String StringJoin(TDoubleArrayList all){
+	public static String StringJoin(DoubleArrayList all){
 		return StringJoin(all.toArray(), ", ");
 	}	
 	
