@@ -2,7 +2,7 @@ package bartMachine;
 
 import java.io.Serializable;
 
-import gnu.trove.list.array.TIntArrayList;
+import it.unimi.dsi.fastutil.ints.IntArrayList;
 
 /**
  * This portion of the code implements the informed prior information on covariates feature.
@@ -16,7 +16,7 @@ public class bartMachine_i_prior_cov_spec extends bartMachine_h_eval implements
 	/** Do we use this feature in this BART model? */
 	protected boolean use_prior_cov_spec;
 	/** This is a probability vector which is the prior on which covariates to split instead of the uniform discrete distribution by default */
-	protected double[] cov_split_prior;	
+	protected double[] cov_split_prior;
 
 	
 	/**
@@ -27,7 +27,7 @@ public class bartMachine_i_prior_cov_spec extends bartMachine_h_eval implements
 	 * @return		The index of the column to split on
 	 */
 	private int pickRandomPredictorThatCanBeAssignedF1(bartMachineTreeNode node){
-		TIntArrayList predictors = node.predictorsThatCouldBeUsedToSplitAtNode();
+		IntArrayList predictors = node.predictorsThatCouldBeUsedToSplitAtNode();
 		//get probs of split prior based on predictors that can be used and weight it accordingly
 		double[] weighted_cov_split_prior_subset = getWeightedCovSplitPriorSubset(predictors);
 		//choose predictor based on random prior value	
@@ -51,14 +51,14 @@ public class bartMachine_i_prior_cov_spec extends bartMachine_h_eval implements
 			return node.padj;
 		}			
 		//pull out weighted cov split prior subset vector
-		TIntArrayList predictors = node.predictorsThatCouldBeUsedToSplitAtNode();
+		IntArrayList predictors = node.predictorsThatCouldBeUsedToSplitAtNode();
 		//get probs of split prior based on predictors that can be used and weight it accordingly
 		double[] weighted_cov_split_prior_subset = getWeightedCovSplitPriorSubset(predictors);	
 		
 		//find index inside predictor vector
 		int index = bartMachineTreeNode.BAD_FLAG_int;
 		for (int i = 0; i < predictors.size(); i++){
-			if (predictors.get(i) == node.splitAttributeM){
+			if (predictors.getInt(i) == node.splitAttributeM){
 				index = i;
 				break;
 			}
@@ -75,10 +75,10 @@ public class bartMachine_i_prior_cov_spec extends bartMachine_h_eval implements
 	 * @param predictors	The indices of the valid covariates
 	 * @return				The updated and renormalized prior probability vector on the covariates to split
 	 */
-	private double[] getWeightedCovSplitPriorSubset(TIntArrayList predictors) {
+	private double[] getWeightedCovSplitPriorSubset(IntArrayList predictors) {
 		double[] weighted_cov_split_prior_subset = new double[predictors.size()];
 		for (int i = 0; i < predictors.size(); i++){
-			weighted_cov_split_prior_subset[i] = cov_split_prior[predictors.get(i)];
+			weighted_cov_split_prior_subset[i] = cov_split_prior[predictors.getInt(i)];
 		}
 		Tools.normalize_array(weighted_cov_split_prior_subset);
 		return weighted_cov_split_prior_subset;
